==> apb-project_2.12-1.0.1-sources.jar: org/mulesoft/apb/project/internal/dependency/UnreachableDependency.scala <==
package org.mulesoft.apb.project.internal.dependency

import amf.core.client.common.validation.SeverityLevels
import amf.core.client.scala.model.document.ExternalFragment
import amf.core.client.scala.validation.AMFValidationResult
import org.mulesoft.apb.project.client.scala.ProjectErrors
import org.mulesoft.apb.project.client.scala.dependency.{ExtensionDependency, ParsedDependency}
import org.mulesoft.apb.project.client.scala.model.{DependencyScope, Gav, ProjectDependency, ProjectDescriptor}
import org.mulesoft.apb.project.internal.dependency.UnreachableDependency.emptyUnit
import org.mulesoft.apb.project.internal.engine.MigrationRisks
import org.mulesoft.apb.project.internal.validations.ProjectValidations.UnreacheableAsset

private[apb] object UnreachableDependency {
  protected val emptyUnit = ExternalFragment().withId("unreachable-unit")

  def apply(descriptor: ProjectDescriptor, dependency: ProjectDependency): ParsedDependency = {
    val validation = AMFValidationResult(s"Asset ${dependency.gav.path} is unreachable",
                                         SeverityLevels.VIOLATION,
                                         "",
                                         None,
                                         UnreacheableAsset.id,
                                         None,
                                         Some(dependency.gav.path),
                                         Unit)
    new UnreachableDependency(descriptor, ProjectErrors(projectErrors = List(validation)), dependency.scope)
  }
}

private[apb] case class UnreachableDependency(override val descriptor: ProjectDescriptor,
                                              override val errors: ProjectErrors,
                                              override val scope: DependencyScope)
    extends ParsedDependency(emptyUnit, descriptor, errors) {

  def update(migrationRisks: MigrationRisks): UnreachableDependency = this
}

==> apb-project_2.12-1.0.3-sources.jar: org/mulesoft/apb/project/internal/dependency/UnreachableDependency.scala <==
package org.mulesoft.apb.project.internal.dependency

import amf.core.client.common.validation.SeverityLevels
import amf.core.client.scala.model.document.ExternalFragment
import amf.core.client.scala.validation.AMFValidationResult
import amf.core.internal.validation.CoreValidations.UnresolvedReference
import org.mulesoft.apb.project.client.scala.ProjectErrors
import org.mulesoft.apb.project.client.scala.dependency.{ExtensionDependency, ParsedDependency}
import org.mulesoft.apb.project.client.scala.model.{DependencyScope, Gav, ProjectDependency, ProjectDescriptor}
import org.mulesoft.apb.project.internal.dependency.UnreachableDependency.emptyUnit
import org.mulesoft.apb.project.internal.engine.MigrationRisks
import org.mulesoft.apb.project.internal.validations.ProjectValidations.UnreacheableAsset

private[apb] object UnreachableDependency {
  val emptyUnit = ExternalFragment().withId("unreachable-unit")

  def apply(descriptor: ProjectDescriptor, dependency: ProjectDependency): ParsedDependency = {
    val validation = AMFValidationResult(s"Asset ${dependency.gav.path} is unreachable",
                                         SeverityLevels.VIOLATION,
                                         "",
                                         None,
                                         UnreacheableAsset.id,
                                         None,
                                         Some(dependency.gav.path),
                                         Unit)
    new UnreachableDependency(descriptor, ProjectErrors(projectErrors = List(validation)), dependency.scope)
  }

  // TODO change
  def fileNotFound(descriptor: ProjectDescriptor, dependency: ProjectDependency, e: Throwable) = {
    val validation = AMFValidationResult(e.getMessage,
                                         SeverityLevels.VIOLATION,
                                         "",
                                         None,
                                         UnresolvedReference.id,
                                         None,
                                         Some(dependency.gav.path),
                                         Unit)
    new UnreachableDependency(descriptor, ProjectErrors(projectErrors = List(validation)), dependency.scope)
  }
}

private[apb] case class UnreachableDependency(override val descriptor: ProjectDescriptor,
                                              override val errors: ProjectErrors,
                                              override val scope: DependencyScope)
    extends ParsedDependency(emptyUnit, descriptor, errors) {

  def update(migrationRisks: MigrationRisks): UnreachableDependency = this
}
